@@ -1,10 +1,10 @@
 package Mnet;
 
-our $VERSION = "5.04";
+our $VERSION = "5.05";
 
 =head1 NAME
 
-Mnet - Testable network automation and reporting
+L<Mnet> - Testable network automation and reporting
 
 =head1 SYNOPSIS
 
@@ -66,7 +66,8 @@ Mnet - Testable network automation and reporting
     $log->info("processing device");
 
     # create an expect ssh session to --device
-    my $ssh = Mnet::Expect::Cli->new({
+    #   perldoc Mnet::Expect shows how to disable ssh host/key checks
+    my $ssh = Mnet::Expect::Cli::Ios->new({
         spawn => [ "ssh", $cli->{device} ],
     });
 
@@ -90,7 +91,7 @@ Mnet - Testable network automation and reporting
 =head1 DESCRIPTION
 
 The Mnet modules are for perl programmers who want to create testable network
-automation and/or reporting scripts.
+automation and/or reporting scripts as simply as possible.
 
 The main features of the Mnet perl modules are:
 
@@ -127,27 +128,29 @@ of automation scripts and allowing for proper regression testing.
 
 =back
 
-Most of the Mnet modules can be used independely of each other, except where
+Most of the Mnet modules can be used independently of each other, unless
 otherwise noted.
 
-Refer to the individual Mnet modules listed in the SEE ALSO section below for
-more detail.
+Refer to the individual Mnet modules listed in the SEE ALSO section below
+for more detail.
 
 =head1 INSTALLATION
 
+The Mnet perl modules should work in just about any unix perl environment.
+
 The latest Mnet release can be installed from CPAN
 
     cpan install Mnet
 
 Or downloaded and installed from L<https://github.com/menzascripting/Mnet>
 
-    tar -xf Mnet-X.y.tar.gz
+    tar -xzf Mnet-X.y.tar.gz
     cd Mnet-X.y
-    perl Makefile.PL # INSTALL_BASE=/different/path
+    perl Makefile.PL  # INSTALL_BASE=/specify/path
     make install
 
-The Mnet perl modules should work in just about any unix perl environment. To
-interact with command line sessions the perl Expect module is required.
+You might need to update your PERL5LIB environment variable if you uncommented
+the INSTALL_BASE option above.
 
 =head1 AUTHOR
 
@@ -197,6 +200,11 @@ L<Mnet::Test>
 
 =cut
 
+# required modules
+#   cpan complians if use strict is missing
+use warnings;
+use strict;
+
 # normal end of package
 1;
 
