@@ -15,17 +15,17 @@ Mnet::Stanza - Manipulate stanza outline text
     $sh_run = Mnet::Stanza::trim($sh_run);
 
     # parse existing version of secure acl from current config
-    my $acl_old = Mnet::Stanza::parse($sh_run, qr/^ip access-list DMZ/);
+    my $acl_old = Mnet::Stanza::parse($sh_run, /^ip access-list SECURE/);
 
     # note latest version of secure acl, trim extra spaces
     my $acl_new = Mnet::Stanza::trim("
-        ip access-list DMZ
+        ip access-list SECURE
          permit 192.168.0.0 0.0.255.255
     ");
 
     # print config to update acl if current acl is different than latest
     if (Mnet::Stanza::diff($acl_old, $acl_new)) {
-        print "no ip access-list DMZ\n" if $acl_old;
+        print "no ip access-list SECURE\n" if $acl_old;
         print "$acl_new\n";
     }
 
@@ -33,16 +33,16 @@ Mnet::Stanza - Manipulate stanza outline text
     my @ints = Mnet::Stanza::parse($sh_run, /^interface/);
     foreach my $int (@ints) {
         next if $int !~ /^\s*shutdown/m;
-        next if $int =~ /^\s*ip access-group DMZ in/m;
+        next if $int =~ /^\s*ip access-group SECURE in/m;
         die "error, $int" if $int !~ /^interface (\S+)/;
         print "interface $1\n";
-        print " ip access-group DMZ in\n";
+        print " ip access-group SECURE in\n";
     }
 
 =head1 DESCRIPTION
 
-Mnet::Stanza can be used on text arranged in stanzas of indented lines or text
-in outline format, such as the following:
+This functions in this module can be used on text arranged in stanzas of
+indented lines or text, perhaps something like this:
 
     line
     stanza 1
@@ -63,11 +63,9 @@ In the above example the following would be true:
     sub-stanza 1 contains two indented lines and a sub-sub-stanza 1
     sub-sub-stanza 1 contains two indented lines
 
-This can be used to parse cisco ios configs, amongst other things.
-
-=head1 FUNCTIONS
-
-Mnet::Stanza implements the functions listed below.
+The functions below can be used to trip extra blank lines and spaces from
+stanza text, to parse stanzas and sub-stanzas, and to copare stanza text
+sections to each other.
 
 =cut
 
@@ -85,8 +83,8 @@ sub trim {
 
     $output = Mnet::Stanza::trim($input)
 
-The Mnet::Stanza::trim function can be used to normalize stanza spacing and may
-be useful before calling the diff function or outputting a stanza to the user.
+The trim function can be used to normalize stanza spacing and may be useful
+before calling the diff function or outputting a stanza to the user.
 
 This function does the following:
 
@@ -139,12 +137,11 @@ sub parse {
 
 =head2 parse
 
-    @output = Mnet::Stanza::parse($input, qr/$match_re/)
-    $output = Mnet::Stanza::parse($input, qr/$match_re/)
+    @output = Mnet::Stanza::parse($input, /$match_re/)
+    $output = Mnet::Stanza::parse($input, /$match_re/)
 
-The Mnet::Stanza::parse function can be used to output one or more matching
-stanza sections from the input text, either as a list of matching stanzas or
-a single string.
+The parse function can be used to output one or more matching stanza sections
+from the input text, either as a list of matching stanzas or a single string.
 
 Here's some sample input text:
 
@@ -163,9 +160,7 @@ Using an input match_re of qr/^interface/ the following two stanzas are output:
     interface Ethernet2
      ip address 1.2.3.4 255.255.255.0
 
-Note that blank lines don't terminate stanzas.
-
-Refer also to the Mnet::Stanza::trim function in this module.
+Refer also to the trim function in this module.
 
 =cut
 
@@ -180,12 +175,12 @@ Refer also to the Mnet::Stanza::trim function in this module.
 
     # loop through lines, set matching output stanzas
     #   use indent var to track indent level of current matched stanza line
-    #   if line matches current indent or is blank then append to output stanza
+    #   if line matches current indent then append to current output stanza
     #   elsif line matches input mathc_re then push to a new output stanza
     #   else reset current indet to undef, to wait for a new match_re line
     my $indent = undef;
     foreach my $line (split(/\n/, $input)) {
-        if (defined $indent and $line =~ /^($indent|\s*$)/) {
+        if (defined $indent and $line =~ /^$indent/) {
             $output[-1] .= "$line\n";
         } elsif ($line =~ $match_re) {
             push @output, "$line\n";
@@ -211,8 +206,8 @@ sub diff {
 
     $diff = Mnet::Stanza::diff($old, $new)
 
-The Mnet::Stanza::diff function checks to see if the input old and new stanza
-strings are the same.
+The diff function checks to see if the input old and new stanza strings are
+the same.
 
 The returned diff value will be set as follows:
 
@@ -222,8 +217,8 @@ The returned diff value will be set as follows:
     line        indicates mismatch line number and line text
     other       indicates mismatch such as extra eol chars at end
 
-Note that blank lines and all other spaces are significant. To remove extra
-spaces use the Mnet::Stanza::trim function before calling this function.
+Note that blank lines and all other spaces are significant. The trim function
+in this module can be used to remove extra spaces before calling this function.
 
 =cut
 
